# -*- coding: utf-8 -*-

from __future__ import division

import shortuuid
from django.conf import settings
from django_logit import logit
from django_response import response

from equipment.models import IsolationPointInfo
from utils.error.errno_utils import IsolationPointStatusCode
from utils.redis.rpoint import get_point_info, set_point_info


@logit
def screen_login(request):
    uuid = shortuuid.uuid()

    return response(data={
        'login_uuid': uuid,
        'login_url': f'{settings.DOMAIN}/api/mp/screen/login?uuid={uuid}',
    })


@logit
def screen_info_set(request):
    uuid = request.POST.get('uuid', '')
    point_id = request.POST.get('point_id', '')

    set_point_info(uuid, point_id)

    return response()


@logit
def screen_info(request):
    uuid = request.POST.get('uuid', '')

    point_id = get_point_info(uuid)

    try:
        point = IsolationPointInfo.objects.get(point_id=point_id, status=True)
    except IsolationPointInfo.DoesNotExist:
        return response(IsolationPointStatusCode.ISOLATIONPOINT_NOT_FOUND)

    return response(data=point.data)
